:mod:`art.defences.transformer.poisoning`
=========================================
.. automodule:: art.defences.transformer.poisoning

Neural Cleanse
--------------
.. autoclass:: NeuralCleanse
   :members:
   :special-members:
